==> qmmp_0.6.3.orig.tar.gz: qmmp-0.6.3/src/plugins/Input/cdaudio/translations/cdaudio_plugin_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="nl">
<context>
    <name>DecoderCDAudioFactory</name>
    <message>
        <location filename="../decodercdaudiofactory.cpp" line="45"/>
        <source>CD Audio Plugin</source>
        <translation>Audio CD Module</translation>
    </message>
    <message>
        <location filename="../decodercdaudiofactory.cpp" line="88"/>
        <source>About CD Audio Plugin</source>
        <translation>Over de Audio CD Module</translation>
    </message>
    <message>
        <location filename="../decodercdaudiofactory.cpp" line="89"/>
        <source>Qmmp CD Audio Plugin</source>
        <translation>Audio CD Module voor Qmmp</translation>
    </message>
    <message>
        <location filename="../decodercdaudiofactory.cpp" line="90"/>
        <source>Compiled against libcdio-%1 and libcddb-%2</source>
        <translation>Gecompileerd tegen libcdio-%1 en libcddb-%2</translation>
    </message>
    <message>
        <location filename="../decodercdaudiofactory.cpp" line="92"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Auteur: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../decodercdaudiofactory.cpp" line="93"/>
        <source>Usage: open cdda:/// using Add URL dialog or command line</source>
        <translation>Gebruik: Voeg cdda:/// in het &quot;Voeg URL toe&quot; dialoog of als argument op de command prompt</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>CD Audio Plugin Settings</source>
        <translation>Audio CD Module Instellingen</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Override device:</source>
        <translation>Gebruikt apparaat:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="42"/>
        <source>Limid cd speed:</source>
        <translation>Beperk CD snelheid:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="62"/>
        <source>Use cd-text</source>
        <translation>Gebruik cd-text</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="69"/>
        <source>CDDB</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="78"/>
        <source>Use HTTP instead of CDDBP</source>
        <translation>Gebruik HTTP i.p.v. CDDBP</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="88"/>
        <source>Server:</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="95"/>
        <source>Path:</source>
        <translation>Pad:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="105"/>
        <source>Port:</source>
        <translation>Poort:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="117"/>
        <source>Clear CDDB cache</source>
        <translation>Leeg CDDB cache</translation>
    </message>
</context>
</TS>

==> qmmp_0.10.5.orig.tar.gz: qmmp-0.10.5/src/plugins/Input/cdaudio/translations/cdaudio_plugin_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="nl">
<context>
    <name>DecoderCDAudioFactory</name>
    <message>
        <location filename="../decodercdaudiofactory.cpp" line="47"/>
        <source>CD Audio Plugin</source>
        <translation>Audio CD Module</translation>
    </message>
    <message>
        <location filename="../decodercdaudiofactory.cpp" line="92"/>
        <source>About CD Audio Plugin</source>
        <translation>Over de Audio CD Module</translation>
    </message>
    <message>
        <location filename="../decodercdaudiofactory.cpp" line="93"/>
        <source>Qmmp CD Audio Plugin</source>
        <translation>Audio CD Module voor Qmmp</translation>
    </message>
    <message>
        <location filename="../decodercdaudiofactory.cpp" line="94"/>
        <source>Compiled against libcdio-%1 and libcddb-%2</source>
        <translation>Gecompileerd tegen libcdio-%1 en libcddb-%2</translation>
    </message>
    <message>
        <location filename="../decodercdaudiofactory.cpp" line="96"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Auteur: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../decodercdaudiofactory.cpp" line="97"/>
        <source>Usage: open cdda:/// using Add URL dialog or command line</source>
        <translation>Gebruik: Voeg cdda:/// in het &quot;Voeg URL toe&quot; dialoog of als argument op de command prompt</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>CD Audio Plugin Settings</source>
        <translation>Audio CD Module Instellingen</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Override device:</source>
        <translation>Gebruikt apparaat:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="42"/>
        <source>Limit cd speed:</source>
        <translation>Beperk CD snelheid:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="62"/>
        <source>Use cd-text</source>
        <translation>Gebruik cd-text</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="69"/>
        <source>CDDB</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="78"/>
        <source>Use HTTP instead of CDDBP</source>
        <translation>Gebruik HTTP i.p.v. CDDBP</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="88"/>
        <source>Server:</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="95"/>
        <source>Path:</source>
        <translation>Pad:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="105"/>
        <source>Port:</source>
        <translation>Poort:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="117"/>
        <source>Clear CDDB cache</source>
        <translation>Leeg CDDB cache</translation>
    </message>
</context>
</TS>
